#!/usr/bin/env python
# setup.py generated by flit for tools that don't yet use PEP 517

from distutils.core import setup

packages = \
['sqc']

package_data = \
{'': ['*']}

install_requires = \
['convtools', 'sqloxide']

extras_require = \
{'test': ['pytest', 'pytest-cov']}

setup(name='sqc',
      version='0.1.0',
      description='SQL queries to collections',
      author='Anexen',
      author_email=None,
      url=None,
      packages=packages,
      package_data=package_data,
      install_requires=install_requires,
      extras_require=extras_require,
     )
